#

##

    	treasuries

    	ranked

    		[ ] config file

    			treasure.JSON {
    				"names": [],
    				"tags": [],

    				#
    				#
    				#
    				"cautions": [],

    				"versions": {
    					"1.0.0": ""
    				}
    			}

    		[ ] rust subdomain proxy:

    			[dir] mediphy_1
    				[dir] trends
    					[dir] mongo_data
    						[mongo:DB]
    							[mongo:collection]

    				[dir] treasures
    					[name].[definition]

    						https://name.1.mediphy:443
    						https://name.2.mediphy:443

    				[dir] mints
    					[name]